using CxxWrap # this is needed for opening the dependency lib. Otherwise Libdl.dlopen fails
using Libdl

const depsfile = joinpath(@__DIR__, "deps.jl")
const FASTJET_DIR = get(ENV, "FASTJET_DIR", nothing)

if FASTJET_DIR === nothing 
    # By default, use FastJet_jll and FastJet_Julia_Wrapper_jll
    open(depsfile, "w") do io
        print(io,
              """
              # This file is automatically generated
              # Do not edit
              using CxxWrap
              using FastJet_jll
              using FastJet_Julia_Wrapper_jll
              check_deps() = nothing
              """
             )
    end
else
    libfastjetwrap = find_library("libfastjetwrap", [FASTJET_DIR])
    isempty(libfastjetwrap) && error("libfastjetwrap not found in $FASTJET_DIR")

    fastjetwrap_size = filesize(dlpath(libfastjetwrap))

    open(depsfile, "w") do io
        println(io,
                """
                # This file is automatically generated
                # Do not edit
                function check_deps()
                    if fastjetwrap_size != filesize(Libdl.dlpath(libfastjetwrap))
                        error("FastJetWrap library has changed, re-run Pkg.build(\\\"FastJet\\\")")
                    end
                end
                """
               )
        println(io, :(const libfastjetwrap = $libfastjetwrap))
        println(io, :(const fastjetwrap_size = $fastjetwrap_size))
    end
end
